@@ -1,5 +1,6 @@
 from distillers import Distill, Distiller
 
+
 class NewsDistiller(Distiller):
     site = Distill("og:site_name")
     title = Distill("s:headline", "og:title")
@@ -11,14 +12,14 @@ class NewsDistiller(Distiller):
     link = Distill("s:url", "og:url")
     id = Distill("s:identifier")
 
+
 class ParselyDistiller(Distiller):
     site = Distill("og:site_name")
     title = Distill("pp:title", "s:headline", "og:title")
     image_url = Distill("pp:image_url", "s:associatedMedia.ImageObject/url", "og:image")
     pub_date = Distill("pp:pub_date", "s:datePublished")
-    author = Distill("pp:author", "s:creator.Person/name")
+    author = Distill("pp:author", "s:creator.Person/name", "s:author")
     section = Distill("pp:section", "s:articleSection")
-    link = Distill("pp:link", "og:url")
+    link = Distill("pp:link", "og:url", "s:url")
     post_id = Distill("pp:post_id", "s:identifier")
     page_type = Distill("pp:type")
-
